@@ -69,10 +69,15 @@ class SlidePlugin(CMSPlugin):
         blank=True,
         choices=LINK_TARGETS,
     )
+    link_text = models.CharField(
+        verbose_name=_('link text'),
+        max_length=200,
+        blank=True
+    )
 
 
     def __unicode__(self):
-        image_text = content_text = None
+        image_text = content_text = ''
 
         if self.image_id:
             image_text = u'%s' % (self.image.name or self.image.original_filename)
